@@ -1,4 +1,17 @@
 # -*- coding: utf-8 -*-
+# Copyright (C) 2020 Red Hat, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
 #
 # Configuration file for the Sphinx documentation builder.
 #
@@ -8,7 +21,6 @@
 
 # -- Project information -----------------------------------------------------
 
-project = 'oslo.upgradecheck'
 copyright = '2018, Oslo Contributors'
 author = 'Oslo Contributors'
 
